searchData={"items":[{"type":"module","title":"Bingex","doc":"Bingex is an Elixir library for interacting with the BingX exchange, providing a transparent and reliable API interface.\n\nThis library offers:\n  - **HTTP API support** for `Swap` and `User` scopes.\n  - **Sockets** for real-time WebSocket price updates and event streaming.\n  - **Validated models** to ensure data reliability.\n  - **Transparent request-response handling**, exposing full exchange responses for independent interpretation.","ref":"Bingex.html"},{"type":"module","title":"Placing an Order - Bingex","doc":"To place an order on the BingX Swap market:\n\n```elixir\nalias Bingex.{Order, Swap}\n\napi_key = \"YOUR_API_KEY\"\nsecret_key = \"YOUR_SECRET_KEY\"\n\norder = %Order{\n  symbol: \"BTC-USDT\",\n  side: :buy,\n  type: :market,\n  price: 65000,\n  quantity: 0.01\n}\n\ncase Swap.create_order(order, api_key, secret_key) do\n  {:ok, response, _meta} -> IO.inspect(response, label: \"Order Placed\")\n  {:error, error, _meta} -> IO.inspect(error, label: \"Order Failed\")\nend\n```","ref":"Bingex.html#module-placing-an-order"},{"type":"module","title":"Fetching SWAP Balance - Bingex","doc":"To retrieve user balances:\n```elixir\nalias Bingex.Swap\n\ncase Swap.get_balance(api_key, secret_key) do\n  {:ok, balance, _meta} -> IO.inspect(balance, label: \"Account Balance\")\n  {:error, error, _meta} -> IO.inspect(error, label: \"Balance Fetch Failed\")\nend\n```","ref":"Bingex.html#module-fetching-swap-balance"},{"type":"module","title":"Sockets - Bingex","doc":"Define and start your WebSocket using Socket implementation (e.g. `Bingex.Swap.PriceSocket`):\n```elixir\ndefmodule PriceSource do\n  use Bingex.Swap.PriceSocket\n  alias Bingex.Swap.PriceSocket\n\n  def start_link(_args \\\\ []) do\n    PriceSocket.start_link(__MODULE__, :state)\n  end\n\n  @impl true\n  def handle_connect(state) do\n    PriceSocket.subscribe(%{symbol: \"BTC-USDT\", type: :last})\n    {:ok, state}\n  end\n\n  @impl true\n  def handle_event(type, event, state) do\n    IO.inspect({type, event, state})\n    {:ok, state}\n  end\nend\n\nPriceSource.start_link()\n```","ref":"Bingex.html#module-sockets"},{"type":"module","title":"Transparency and Reliability - Bingex","doc":"Bingex ensures that all API responses remain fully accessible with a really tiny abstraction,\nallowing users to interpret and validate responses as needed. The library follows a simple but\npragmatic approach, ensuring secure and predictable request handling.","ref":"Bingex.html#module-transparency-and-reliability"},{"type":"module","title":"Bingex.Types","doc":"","ref":"Bingex.Types.html"},{"type":"type","title":"Bingex.Types.failed_request_metadata/0","doc":"","ref":"Bingex.Types.html#t:failed_request_metadata/0"},{"type":"type","title":"Bingex.Types.request_metadata/0","doc":"","ref":"Bingex.Types.html#t:request_metadata/0"},{"type":"module","title":"Bingex.Model.Order","doc":"Defines the structure and types for orders in BingX.","ref":"Bingex.Model.Order.html"},{"type":"type","title":"Bingex.Model.Order.execution_type/0","doc":"","ref":"Bingex.Model.Order.html#t:execution_type/0"},{"type":"type","title":"Bingex.Model.Order.margin_mode/0","doc":"","ref":"Bingex.Model.Order.html#t:margin_mode/0"},{"type":"function","title":"Bingex.Model.Order.new/1","doc":"","ref":"Bingex.Model.Order.html#new/1"},{"type":"type","title":"Bingex.Model.Order.position_side/0","doc":"","ref":"Bingex.Model.Order.html#t:position_side/0"},{"type":"type","title":"Bingex.Model.Order.side/0","doc":"","ref":"Bingex.Model.Order.html#t:side/0"},{"type":"type","title":"Bingex.Model.Order.status/0","doc":"","ref":"Bingex.Model.Order.html#t:status/0"},{"type":"type","title":"Bingex.Model.Order.t/0","doc":"","ref":"Bingex.Model.Order.html#t:t/0"},{"type":"type","title":"Bingex.Model.Order.type/0","doc":"","ref":"Bingex.Model.Order.html#t:type/0"},{"type":"type","title":"Bingex.Model.Order.working_type/0","doc":"","ref":"Bingex.Model.Order.html#t:working_type/0"},{"type":"module","title":"Bingex.User","doc":"Provides an interface to interact with the BingX User API.","ref":"Bingex.User.html"},{"type":"function","title":"Bingex.User.extend_listen_key/2","doc":"","ref":"Bingex.User.html#extend_listen_key/2"},{"type":"function","title":"Bingex.User.generate_listen_key/1","doc":"","ref":"Bingex.User.html#generate_listen_key/1"},{"type":"function","title":"Bingex.User.get_referral/3","doc":"","ref":"Bingex.User.html#get_referral/3"},{"type":"function","title":"Bingex.User.get_referrals/6","doc":"","ref":"Bingex.User.html#get_referrals/6"},{"type":"module","title":"Bingex.User.Model.ReferralInfo","doc":"Represents referral information for a user in BingX.","ref":"Bingex.User.Model.ReferralInfo.html"},{"type":"function","title":"Bingex.User.Model.ReferralInfo.decode/1","doc":"","ref":"Bingex.User.Model.ReferralInfo.html#decode/1"},{"type":"type","title":"Bingex.User.Model.ReferralInfo.t/0","doc":"Referral information for a user.","ref":"Bingex.User.Model.ReferralInfo.html#t:t/0"},{"type":"module","title":"Bingex.User.Data.GenerateListenKey","doc":"Represents the listen key data for user authentication in BingX.","ref":"Bingex.User.Data.GenerateListenKey.html"},{"type":"function","title":"Bingex.User.Data.GenerateListenKey.decode/1","doc":"","ref":"Bingex.User.Data.GenerateListenKey.html#decode/1"},{"type":"function","title":"Bingex.User.Data.GenerateListenKey.embed_in_reply/1","doc":"","ref":"Bingex.User.Data.GenerateListenKey.html#embed_in_reply/1"},{"type":"type","title":"Bingex.User.Data.GenerateListenKey.t/0","doc":"","ref":"Bingex.User.Data.GenerateListenKey.html#t:t/0"},{"type":"module","title":"Bingex.User.Data.GetReferral","doc":"Retrieves and structures referral data for a user in BingX.","ref":"Bingex.User.Data.GetReferral.html"},{"type":"function","title":"Bingex.User.Data.GetReferral.decode/1","doc":"","ref":"Bingex.User.Data.GetReferral.html#decode/1"},{"type":"function","title":"Bingex.User.Data.GetReferral.embed_in_reply/1","doc":"","ref":"Bingex.User.Data.GetReferral.html#embed_in_reply/1"},{"type":"type","title":"Bingex.User.Data.GetReferral.t/0","doc":"","ref":"Bingex.User.Data.GetReferral.html#t:t/0"},{"type":"module","title":"Bingex.User.Data.GetReferrals","doc":"Retrieves and structures a list of referral data for a user in BingX.","ref":"Bingex.User.Data.GetReferrals.html"},{"type":"function","title":"Bingex.User.Data.GetReferrals.decode/1","doc":"","ref":"Bingex.User.Data.GetReferrals.html#decode/1"},{"type":"function","title":"Bingex.User.Data.GetReferrals.embed_in_reply/1","doc":"","ref":"Bingex.User.Data.GetReferrals.html#embed_in_reply/1"},{"type":"type","title":"Bingex.User.Data.GetReferrals.t/0","doc":"","ref":"Bingex.User.Data.GetReferrals.html#t:t/0"},{"type":"module","title":"Bingex.Swap","doc":"Provides an interface to interact with the BingX Swap API.","ref":"Bingex.Swap.html"},{"type":"function","title":"Bingex.Swap.cancel_all_orders/3","doc":"Requests to cancel all orders by their market symbol (ex. BTC-USDT) with account credentials.","ref":"Bingex.Swap.html#cancel_all_orders/3"},{"type":"function","title":"Bingex.Swap.close_all_positions/3","doc":"Request to close all positions by market symbol (ex. BTC-USDT) with account credentials.","ref":"Bingex.Swap.html#close_all_positions/3"},{"type":"function","title":"Bingex.Swap.get_balance/2","doc":"Requests to get current swap balance.","ref":"Bingex.Swap.html#get_balance/2"},{"type":"function","title":"Bingex.Swap.get_contracts/1","doc":"","ref":"Bingex.Swap.html#get_contracts/1"},{"type":"function","title":"Bingex.Swap.get_leverage/3","doc":"Request the opening leverage and available positions of the user in the specified symbol contract.","ref":"Bingex.Swap.html#get_leverage/3"},{"type":"function","title":"Bingex.Swap.get_orders_history/6","doc":"Request to get all user's orders (pending, active, ...) by an optional\nperiod (start_time, end_time) and an optional limit of returned amount\nof orders with account credentials.","ref":"Bingex.Swap.html#get_orders_history/6"},{"type":"function","title":"Bingex.Swap.get_positions/3","doc":"Request to the positions state of perpetual contracts by with account credentials.","ref":"Bingex.Swap.html#get_positions/3"},{"type":"function","title":"Bingex.Swap.get_positions_history/5","doc":"Request to the position history of perpetual contracts by an optional\nperiod (start_time, end_time) with account credentials.","ref":"Bingex.Swap.html#get_positions_history/5"},{"type":"function","title":"Bingex.Swap.get_quotes/1","doc":"","ref":"Bingex.Swap.html#get_quotes/1"},{"type":"function","title":"Bingex.Swap.get_server_time/0","doc":"Requests to get current server time.","ref":"Bingex.Swap.html#get_server_time/0"},{"type":"function","title":"Bingex.Swap.place_order/3","doc":"Requests to place an order using order data with account credentials.","ref":"Bingex.Swap.html#place_order/3"},{"type":"function","title":"Bingex.Swap.place_orders/3","doc":"Requests to place bunch of orders using list of order data with account credentials.","ref":"Bingex.Swap.html#place_orders/3"},{"type":"function","title":"Bingex.Swap.place_test_order/3","doc":"Requests to place a test order using order data with account credentials.","ref":"Bingex.Swap.html#place_test_order/3"},{"type":"function","title":"Bingex.Swap.set_leverage/5","doc":"Request to set user's leverage amount by market symbol, position side and account credentials.\nPosition side can be either `:crossed` or `:isolated`.\nCurrently, BingX allows leverage from 1 to 125.","ref":"Bingex.Swap.html#set_leverage/5"},{"type":"function","title":"Bingex.Swap.set_margin_mode/4","doc":"Request to set user's margin mode by market symbol and account credentials.\nMargin mode can be either `:crossed` or `:isolated`.","ref":"Bingex.Swap.html#set_margin_mode/4"},{"type":"behaviour","title":"Bingex.Swap.EventSocket","doc":"```elixir\ndefmodule EventSource do\n  use Bingex.Swap.EventSocket\n  require Logger\n  alias Bingex.Swap.EventSocket\n\n  def start_link(listen_key) do\n    EventSocket.start_link(listen_key, __MODULE__, :state)\n  end\n\n  @impl true\n  def handle_event(type, event, state) do\n    Logger.info(%{ type: type, event: event, state: state })\n    {:ok, state}\n  end\nend\n```","ref":"Bingex.Swap.EventSocket.html"},{"type":"function","title":"Bingex.Swap.EventSocket.call/3","doc":"","ref":"Bingex.Swap.EventSocket.html#call/3"},{"type":"function","title":"Bingex.Swap.EventSocket.cast/2","doc":"","ref":"Bingex.Swap.EventSocket.html#cast/2"},{"type":"callback","title":"Bingex.Swap.EventSocket.handle_event/3","doc":"","ref":"Bingex.Swap.EventSocket.html#c:handle_event/3"},{"type":"function","title":"Bingex.Swap.EventSocket.start/4","doc":"","ref":"Bingex.Swap.EventSocket.html#start/4"},{"type":"function","title":"Bingex.Swap.EventSocket.start_link/4","doc":"","ref":"Bingex.Swap.EventSocket.html#start_link/4"},{"type":"behaviour","title":"Bingex.Swap.PriceSocket","doc":"```elixir\ndefmodule PriceSource do\n  use Bingex.Swap.PriceSocket\n  alias Bingex.Swap.PriceSocket\n\n  def start_link(_args \\\\ []) do\n    PriceSocket.start_link(__MODULE__, :state)\n  end\n\n  @impl true\n  def handle_connect(state) do\n    PriceSocket.subscribe(symbol: \"BTC-USDT\", type: :last)\n    {:ok, state}\n  end\n\n  @impl true\n  def handle_event(type, event, state) do\n    IO.inspect({type, event, state})\n    {:ok, state}\n  end\nend\n```","ref":"Bingex.Swap.PriceSocket.html"},{"type":"function","title":"Bingex.Swap.PriceSocket.call/3","doc":"","ref":"Bingex.Swap.PriceSocket.html#call/3"},{"type":"function","title":"Bingex.Swap.PriceSocket.cast/2","doc":"","ref":"Bingex.Swap.PriceSocket.html#cast/2"},{"type":"callback","title":"Bingex.Swap.PriceSocket.handle_event/3","doc":"","ref":"Bingex.Swap.PriceSocket.html#c:handle_event/3"},{"type":"function","title":"Bingex.Swap.PriceSocket.start/3","doc":"","ref":"Bingex.Swap.PriceSocket.html#start/3"},{"type":"function","title":"Bingex.Swap.PriceSocket.start_link/3","doc":"","ref":"Bingex.Swap.PriceSocket.html#start_link/3"},{"type":"function","title":"Bingex.Swap.PriceSocket.subscribe/2","doc":"","ref":"Bingex.Swap.PriceSocket.html#subscribe/2"},{"type":"module","title":"Bingex.Swap.Model.BalanceInfo","doc":"Represents balance information for a BingX swap account.\n\nThis module provides structured details about a user's account balance, including margin availability,\nequity, and profit/loss metrics.","ref":"Bingex.Swap.Model.BalanceInfo.html"},{"type":"function","title":"Bingex.Swap.Model.BalanceInfo.decode/1","doc":"","ref":"Bingex.Swap.Model.BalanceInfo.html#decode/1"},{"type":"type","title":"Bingex.Swap.Model.BalanceInfo.t/0","doc":"","ref":"Bingex.Swap.Model.BalanceInfo.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Model.ContractInfo","doc":"Represents contract information for a swap contract in BingX.","ref":"Bingex.Swap.Model.ContractInfo.html"},{"type":"type","title":"Bingex.Swap.Model.ContractInfo.contract_status/0","doc":"","ref":"Bingex.Swap.Model.ContractInfo.html#t:contract_status/0"},{"type":"function","title":"Bingex.Swap.Model.ContractInfo.decode/1","doc":"","ref":"Bingex.Swap.Model.ContractInfo.html#decode/1"},{"type":"type","title":"Bingex.Swap.Model.ContractInfo.t/0","doc":"","ref":"Bingex.Swap.Model.ContractInfo.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Model.DetailedOrderInfo","doc":"Represents detailed order information for a swap contract in BingX.","ref":"Bingex.Swap.Model.DetailedOrderInfo.html"},{"type":"function","title":"Bingex.Swap.Model.DetailedOrderInfo.decode/1","doc":"Complete order information.\n\nFields:\n  - `order_id` (binary): Unique identifier for the order.\n  - `symbol` (binary): Trading pair symbol (e.g., \"BTC-USDT\").\n  - `side` (`Order.side()`): Buy/Sell direction of the order.\n  - `position_side` (`Order.position_side()`): Position type (e.g., `long`, `short`).\n  - `status` (`Order.status()`): Current status of the order (e.g., `filled`, `canceled`).\n  - `stop_price` (float): Stop price for conditional orders.\n  - `price` (float): Price at which the order was placed.\n  - `type` (`Order.type()`): Order type (e.g., `market`, `limit`).\n  - `client_order_id` (binary): Custom client-provided order ID.\n  - `trigger_order_id` (binary | nil): ID of the trigger order (if applicable).\n  - `working_type` (`Order.working_type()`): Price type used for stop orders.\n  - `leverage` (integer): Leverage level applied to the order.\n  - `fee` (float): Trading fee incurred.\n  - `executed_quote_amount` (float): Total executed quote asset amount.\n  - `executed_quantity` (float): Total executed base asset quantity.\n  - `only_one_position?` (boolean): Whether the order allows only one position.\n  - `order_type` (binary): Additional classification of the order type.\n  - `original_quantity` (float): Initial order quantity.\n  - `average_price` (float): Average execution price of the order.\n  - `position_id` (binary | nil): Associated position ID.\n  - `profit` (float): Realized profit from the order.\n  - `reduce_only?` (boolean): Whether the order reduces an existing position.\n  - `stop_loss` (map | nil): Stop-loss details (if applicable).\n  - `stop_loss_entrust_price` (float): Price at which stop-loss is triggered.\n  - `take_profit` (map | nil): Take-profit details (if applicable).\n  - `take_profit_entrust_price` (float): Price at which take-profit is triggered.\n  - `stop_guaranteed?` (boolean): Whether stop-loss is guaranteed.\n  - `timestamp` (non_neg_integer): Order creation timestamp.\n  - `update_time` (non_neg_integer): Last update timestamp.","ref":"Bingex.Swap.Model.DetailedOrderInfo.html#decode/1"},{"type":"type","title":"Bingex.Swap.Model.DetailedOrderInfo.t/0","doc":"","ref":"Bingex.Swap.Model.DetailedOrderInfo.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Model.DetailedPositionUpdate","doc":"Represents detailed position update information for a swap contract in BingX.","ref":"Bingex.Swap.Model.DetailedPositionUpdate.html"},{"type":"function","title":"Bingex.Swap.Model.DetailedPositionUpdate.decode/1","doc":"","ref":"Bingex.Swap.Model.DetailedPositionUpdate.html#decode/1"},{"type":"type","title":"Bingex.Swap.Model.DetailedPositionUpdate.t/0","doc":"","ref":"Bingex.Swap.Model.DetailedPositionUpdate.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Model.OrderInfo","doc":"Represents order information for a swap contract in BingX.","ref":"Bingex.Swap.Model.OrderInfo.html"},{"type":"function","title":"Bingex.Swap.Model.OrderInfo.decode/1","doc":"","ref":"Bingex.Swap.Model.OrderInfo.html#decode/1"},{"type":"type","title":"Bingex.Swap.Model.OrderInfo.t/0","doc":"","ref":"Bingex.Swap.Model.OrderInfo.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Model.PositionInfo","doc":"Decodes individual position data returned by the BingX swap API.","ref":"Bingex.Swap.Model.PositionInfo.html"},{"type":"function","title":"Bingex.Swap.Model.PositionInfo.decode/1","doc":"","ref":"Bingex.Swap.Model.PositionInfo.html#decode/1"},{"type":"type","title":"Bingex.Swap.Model.PositionInfo.t/0","doc":"","ref":"Bingex.Swap.Model.PositionInfo.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Model.PositionUpdate","doc":"Represents position update information for a swap contract in BingX.","ref":"Bingex.Swap.Model.PositionUpdate.html"},{"type":"function","title":"Bingex.Swap.Model.PositionUpdate.decode/1","doc":"","ref":"Bingex.Swap.Model.PositionUpdate.html#decode/1"},{"type":"type","title":"Bingex.Swap.Model.PositionUpdate.t/0","doc":"","ref":"Bingex.Swap.Model.PositionUpdate.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Model.QuoteInfo","doc":"Represents real-time quote information for a swap contract in BingX.","ref":"Bingex.Swap.Model.QuoteInfo.html"},{"type":"function","title":"Bingex.Swap.Model.QuoteInfo.decode/1","doc":"","ref":"Bingex.Swap.Model.QuoteInfo.html#decode/1"},{"type":"type","title":"Bingex.Swap.Model.QuoteInfo.t/0","doc":"","ref":"Bingex.Swap.Model.QuoteInfo.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Model.WalletUpdate","doc":"Represents a wallet balance update event for a swap account in BingX.","ref":"Bingex.Swap.Model.WalletUpdate.html"},{"type":"function","title":"Bingex.Swap.Model.WalletUpdate.decode/1","doc":"","ref":"Bingex.Swap.Model.WalletUpdate.html#decode/1"},{"type":"type","title":"Bingex.Swap.Model.WalletUpdate.t/0","doc":"","ref":"Bingex.Swap.Model.WalletUpdate.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.CancelAllOrders","doc":"Parses and structures response data for closing all swap positions on BingX.","ref":"Bingex.Swap.Data.CancelAllOrders.html"},{"type":"function","title":"Bingex.Swap.Data.CancelAllOrders.decode/1","doc":"","ref":"Bingex.Swap.Data.CancelAllOrders.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.CancelAllOrders.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.CancelAllOrders.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.CancelAllOrders.t/0","doc":"","ref":"Bingex.Swap.Data.CancelAllOrders.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.CloseAllPositions","doc":"Parses and structures response data for closing all swap positions on BingX.","ref":"Bingex.Swap.Data.CloseAllPositions.html"},{"type":"function","title":"Bingex.Swap.Data.CloseAllPositions.decode/1","doc":"","ref":"Bingex.Swap.Data.CloseAllPositions.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.CloseAllPositions.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.CloseAllPositions.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.CloseAllPositions.t/0","doc":"","ref":"Bingex.Swap.Data.CloseAllPositions.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.GetBalance","doc":"Parses and structures balance data for BingX swap accounts.","ref":"Bingex.Swap.Data.GetBalance.html"},{"type":"function","title":"Bingex.Swap.Data.GetBalance.decode/1","doc":"","ref":"Bingex.Swap.Data.GetBalance.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.GetBalance.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.GetBalance.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.GetBalance.t/0","doc":"","ref":"Bingex.Swap.Data.GetBalance.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.GetContracts","doc":"Parses and structures contract data for BingX swap markets.","ref":"Bingex.Swap.Data.GetContracts.html"},{"type":"function","title":"Bingex.Swap.Data.GetContracts.decode/1","doc":"","ref":"Bingex.Swap.Data.GetContracts.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.GetContracts.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.GetContracts.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.GetContracts.t/0","doc":"","ref":"Bingex.Swap.Data.GetContracts.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.GetLeverage","doc":"Processes leverage info response data for BingX swaps.","ref":"Bingex.Swap.Data.GetLeverage.html"},{"type":"function","title":"Bingex.Swap.Data.GetLeverage.decode/1","doc":"","ref":"Bingex.Swap.Data.GetLeverage.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.GetLeverage.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.GetLeverage.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.GetLeverage.t/0","doc":"","ref":"Bingex.Swap.Data.GetLeverage.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.GetOrdersHistory","doc":"Parses and structures historical order data for BingX swaps.","ref":"Bingex.Swap.Data.GetOrdersHistory.html"},{"type":"function","title":"Bingex.Swap.Data.GetOrdersHistory.decode/1","doc":"","ref":"Bingex.Swap.Data.GetOrdersHistory.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.GetOrdersHistory.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.GetOrdersHistory.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.GetOrdersHistory.t/0","doc":"","ref":"Bingex.Swap.Data.GetOrdersHistory.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.GetPositions","doc":"Parses and structures positions data for BingX swaps.","ref":"Bingex.Swap.Data.GetPositions.html"},{"type":"function","title":"Bingex.Swap.Data.GetPositions.decode/1","doc":"","ref":"Bingex.Swap.Data.GetPositions.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.GetPositions.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.GetPositions.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.GetPositions.t/0","doc":"","ref":"Bingex.Swap.Data.GetPositions.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.GetPositionsHistory","doc":"Parses and structures historical positions data for BingX swaps.","ref":"Bingex.Swap.Data.GetPositionsHistory.html"},{"type":"function","title":"Bingex.Swap.Data.GetPositionsHistory.decode/1","doc":"","ref":"Bingex.Swap.Data.GetPositionsHistory.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.GetPositionsHistory.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.GetPositionsHistory.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.GetPositionsHistory.t/0","doc":"","ref":"Bingex.Swap.Data.GetPositionsHistory.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.GetQuotes","doc":"Parses and structures quote data for BingX swaps.","ref":"Bingex.Swap.Data.GetQuotes.html"},{"type":"function","title":"Bingex.Swap.Data.GetQuotes.decode/1","doc":"","ref":"Bingex.Swap.Data.GetQuotes.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.GetQuotes.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.GetQuotes.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.GetQuotes.t/0","doc":"","ref":"Bingex.Swap.Data.GetQuotes.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.GetServerTime","doc":"Parses and structures server time data for BingX swaps.","ref":"Bingex.Swap.Data.GetServerTime.html"},{"type":"function","title":"Bingex.Swap.Data.GetServerTime.decode/1","doc":"","ref":"Bingex.Swap.Data.GetServerTime.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.GetServerTime.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.GetServerTime.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.GetServerTime.t/0","doc":"","ref":"Bingex.Swap.Data.GetServerTime.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.PlaceOrder","doc":"Parses and structures order placement data for BingX swaps.","ref":"Bingex.Swap.Data.PlaceOrder.html"},{"type":"function","title":"Bingex.Swap.Data.PlaceOrder.decode/1","doc":"","ref":"Bingex.Swap.Data.PlaceOrder.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.PlaceOrder.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.PlaceOrder.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.PlaceOrder.t/0","doc":"","ref":"Bingex.Swap.Data.PlaceOrder.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.PlaceOrders","doc":"Parses and structures batch order placement data for BingX swaps.","ref":"Bingex.Swap.Data.PlaceOrders.html"},{"type":"function","title":"Bingex.Swap.Data.PlaceOrders.decode/1","doc":"","ref":"Bingex.Swap.Data.PlaceOrders.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.PlaceOrders.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.PlaceOrders.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.PlaceOrders.t/0","doc":"","ref":"Bingex.Swap.Data.PlaceOrders.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.PlaceTestOrder","doc":"Parses and structures test order placement data for BingX swaps.","ref":"Bingex.Swap.Data.PlaceTestOrder.html"},{"type":"function","title":"Bingex.Swap.Data.PlaceTestOrder.decode/1","doc":"","ref":"Bingex.Swap.Data.PlaceTestOrder.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.PlaceTestOrder.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.PlaceTestOrder.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.PlaceTestOrder.t/0","doc":"","ref":"Bingex.Swap.Data.PlaceTestOrder.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Data.SetLeverage","doc":"Processes leverage setting response data for BingX swaps.","ref":"Bingex.Swap.Data.SetLeverage.html"},{"type":"function","title":"Bingex.Swap.Data.SetLeverage.decode/1","doc":"","ref":"Bingex.Swap.Data.SetLeverage.html#decode/1"},{"type":"function","title":"Bingex.Swap.Data.SetLeverage.embed_in_reply/1","doc":"","ref":"Bingex.Swap.Data.SetLeverage.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.Data.SetLeverage.t/0","doc":"","ref":"Bingex.Swap.Data.SetLeverage.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Model.AccountEvent","doc":"Represents an account event in BingX swaps.","ref":"Bingex.Swap.Model.AccountEvent.html"},{"type":"function","title":"Bingex.Swap.Model.AccountEvent.decode/1","doc":"","ref":"Bingex.Swap.Model.AccountEvent.html#decode/1"},{"type":"type","title":"Bingex.Swap.Model.AccountEvent.event_type/0","doc":"","ref":"Bingex.Swap.Model.AccountEvent.html#t:event_type/0"},{"type":"type","title":"Bingex.Swap.Model.AccountEvent.t/0","doc":"","ref":"Bingex.Swap.Model.AccountEvent.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Model.ConfigEvent","doc":"Represents a configuration event in BingX swaps.","ref":"Bingex.Swap.Model.ConfigEvent.html"},{"type":"function","title":"Bingex.Swap.Model.ConfigEvent.decode/1","doc":"","ref":"Bingex.Swap.Model.ConfigEvent.html#decode/1"},{"type":"type","title":"Bingex.Swap.Model.ConfigEvent.t/0","doc":"","ref":"Bingex.Swap.Model.ConfigEvent.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Model.PriceEvent","doc":"Handles price events in BingX swaps.","ref":"Bingex.Swap.Model.PriceEvent.html"},{"type":"function","title":"Bingex.Swap.Model.PriceEvent.decode/1","doc":"","ref":"Bingex.Swap.Model.PriceEvent.html#decode/1"},{"type":"type","title":"Bingex.Swap.Model.PriceEvent.t/0","doc":"","ref":"Bingex.Swap.Model.PriceEvent.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Model.TradeEvent","doc":"Processes trade events in BingX swaps.","ref":"Bingex.Swap.Model.TradeEvent.html"},{"type":"function","title":"Bingex.Swap.Model.TradeEvent.decode/1","doc":"","ref":"Bingex.Swap.Model.TradeEvent.html#decode/1"},{"type":"type","title":"Bingex.Swap.Model.TradeEvent.t/0","doc":"","ref":"Bingex.Swap.Model.TradeEvent.html#t:t/0"},{"type":"exception","title":"Bingex.API.Error","doc":"Represents an error that occurs within the BingX API.","ref":"Bingex.API.Error.html"},{"type":"type","title":"Bingex.API.Error.t/0","doc":"","ref":"Bingex.API.Error.html#t:t/0"},{"type":"module","title":"Bingex.API.Reply","doc":"Represents a standardized API response from BingX.","ref":"Bingex.API.Reply.html"},{"type":"type","title":"Bingex.API.Reply.code/0","doc":"","ref":"Bingex.API.Reply.html#t:code/0"},{"type":"type","title":"Bingex.API.Reply.data/0","doc":"","ref":"Bingex.API.Reply.html#t:data/0"},{"type":"type","title":"Bingex.API.Reply.message/0","doc":"","ref":"Bingex.API.Reply.html#t:message/0"},{"type":"function","title":"Bingex.API.Reply.put_data/2","doc":"","ref":"Bingex.API.Reply.html#put_data/2"},{"type":"type","title":"Bingex.API.Reply.t/0","doc":"","ref":"Bingex.API.Reply.html#t:t/0"},{"type":"type","title":"Bingex.API.Reply.t/1","doc":"","ref":"Bingex.API.Reply.html#t:t/1"},{"type":"behaviour","title":"Bingex.Socket","doc":"Provides an abstraction over WebSocket connections for BingX.","ref":"Bingex.Socket.html"},{"type":"function","title":"Bingex.Socket.call/3","doc":"Sends a synchronous message.","ref":"Bingex.Socket.html#call/3"},{"type":"function","title":"Bingex.Socket.cast/2","doc":"Sends an asynchronous message.","ref":"Bingex.Socket.html#cast/2"},{"type":"type","title":"Bingex.Socket.event/0","doc":"","ref":"Bingex.Socket.html#t:event/0"},{"type":"callback","title":"Bingex.Socket.handle_call/3","doc":"","ref":"Bingex.Socket.html#c:handle_call/3"},{"type":"callback","title":"Bingex.Socket.handle_cast/2","doc":"","ref":"Bingex.Socket.html#c:handle_cast/2"},{"type":"callback","title":"Bingex.Socket.handle_connect/1","doc":"","ref":"Bingex.Socket.html#c:handle_connect/1"},{"type":"callback","title":"Bingex.Socket.handle_disconnect/2","doc":"","ref":"Bingex.Socket.html#c:handle_disconnect/2"},{"type":"callback","title":"Bingex.Socket.handle_event/2","doc":"","ref":"Bingex.Socket.html#c:handle_event/2"},{"type":"callback","title":"Bingex.Socket.handle_info/2","doc":"","ref":"Bingex.Socket.html#c:handle_info/2"},{"type":"type","title":"Bingex.Socket.message/0","doc":"","ref":"Bingex.Socket.html#t:message/0"},{"type":"function","title":"Bingex.Socket.send/2","doc":"Sends a message to the process to the specified PID.","ref":"Bingex.Socket.html#send/2"},{"type":"function","title":"Bingex.Socket.start/4","doc":"Starts a WebSocket process.","ref":"Bingex.Socket.html#start/4"},{"type":"function","title":"Bingex.Socket.start_link/4","doc":"Starts a WebSocket process linked to the current process.","ref":"Bingex.Socket.html#start_link/4"},{"type":"type","title":"Bingex.Socket.state/0","doc":"","ref":"Bingex.Socket.html#t:state/0"},{"type":"function","title":"Bingex.Socket.whereis/1","doc":"Returns the `pid` of a Socket process, `nil` otherwise.","ref":"Bingex.Socket.html#whereis/1"},{"type":"exception","title":"Bingex.HTTP.Error","doc":"Represents an HTTP error (based on `Mint.HTTPError`).","ref":"Bingex.HTTP.Error.html"},{"type":"type","title":"Bingex.HTTP.Error.t/0","doc":"","ref":"Bingex.HTTP.Error.html#t:t/0"},{"type":"module","title":"Bingex.HTTP.Request","doc":"Represents HTTP request payload for the BingX API.","ref":"Bingex.HTTP.Request.html"},{"type":"function","title":"Bingex.HTTP.Request.auth_headers/2","doc":"","ref":"Bingex.HTTP.Request.html#auth_headers/2"},{"type":"type","title":"Bingex.HTTP.Request.body/0","doc":"","ref":"Bingex.HTTP.Request.html#t:body/0"},{"type":"function","title":"Bingex.HTTP.Request.build_url/3","doc":"","ref":"Bingex.HTTP.Request.html#build_url/3"},{"type":"type","title":"Bingex.HTTP.Request.headers/0","doc":"","ref":"Bingex.HTTP.Request.html#t:headers/0"},{"type":"type","title":"Bingex.HTTP.Request.method/0","doc":"","ref":"Bingex.HTTP.Request.html#t:method/0"},{"type":"function","title":"Bingex.HTTP.Request.new/4","doc":"","ref":"Bingex.HTTP.Request.html#new/4"},{"type":"type","title":"Bingex.HTTP.Request.options/0","doc":"","ref":"Bingex.HTTP.Request.html#t:options/0"},{"type":"type","title":"Bingex.HTTP.Request.params/0","doc":"","ref":"Bingex.HTTP.Request.html#t:params/0"},{"type":"type","title":"Bingex.HTTP.Request.path/0","doc":"","ref":"Bingex.HTTP.Request.html#t:path/0"},{"type":"function","title":"Bingex.HTTP.Request.set_recv_window/2","doc":"","ref":"Bingex.HTTP.Request.html#set_recv_window/2"},{"type":"function","title":"Bingex.HTTP.Request.set_signature/2","doc":"","ref":"Bingex.HTTP.Request.html#set_signature/2"},{"type":"function","title":"Bingex.HTTP.Request.set_timestamp/1","doc":"","ref":"Bingex.HTTP.Request.html#set_timestamp/1"},{"type":"type","title":"Bingex.HTTP.Request.t/0","doc":"","ref":"Bingex.HTTP.Request.html#t:t/0"},{"type":"type","title":"Bingex.HTTP.Request.url/0","doc":"","ref":"Bingex.HTTP.Request.html#t:url/0"},{"type":"module","title":"Bingex.HTTP.Response","doc":"Represents an HTTP response from the BingX API.","ref":"Bingex.HTTP.Response.html"},{"type":"type","title":"Bingex.HTTP.Response.t/0","doc":"","ref":"Bingex.HTTP.Response.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}